==> apache-arrow-16.1.0_2.arm64_ventura.bottle.tar.gz: apache-arrow/16.1.0_2/lib/cmake/Gandiva/GandivaTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Gandiva::gandiva_shared" for configuration "RELEASE"
set_property(TARGET Gandiva::gandiva_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Gandiva::gandiva_shared PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "re2::re2"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgandiva.1601.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/16.1.0_2/lib/libgandiva.1601.dylib"
  )

list(APPEND _cmake_import_check_targets Gandiva::gandiva_shared )
list(APPEND _cmake_import_check_files_for_Gandiva::gandiva_shared "${_IMPORT_PREFIX}/lib/libgandiva.1601.0.0.dylib" )

# Import target "Gandiva::gandiva_static" for configuration "RELEASE"
set_property(TARGET Gandiva::gandiva_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Gandiva::gandiva_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgandiva.a"
  )

list(APPEND _cmake_import_check_targets Gandiva::gandiva_static )
list(APPEND _cmake_import_check_files_for_Gandiva::gandiva_static "${_IMPORT_PREFIX}/lib/libgandiva.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> apache-arrow-18.0.0.arm64_ventura.bottle.tar.gz: apache-arrow/18.0.0/lib/cmake/Gandiva/GandivaTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Gandiva::gandiva_shared" for configuration "RELEASE"
set_property(TARGET Gandiva::gandiva_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Gandiva::gandiva_shared PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "re2::re2"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgandiva.1800.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/18.0.0/lib/libgandiva.1800.dylib"
  )

list(APPEND _cmake_import_check_targets Gandiva::gandiva_shared )
list(APPEND _cmake_import_check_files_for_Gandiva::gandiva_shared "${_IMPORT_PREFIX}/lib/libgandiva.1800.0.0.dylib" )

# Import target "Gandiva::gandiva_static" for configuration "RELEASE"
set_property(TARGET Gandiva::gandiva_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Gandiva::gandiva_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgandiva.a"
  )

list(APPEND _cmake_import_check_targets Gandiva::gandiva_static )
list(APPEND _cmake_import_check_files_for_Gandiva::gandiva_static "${_IMPORT_PREFIX}/lib/libgandiva.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
